@@ -103,7 +103,7 @@
 #' \code{\link{plot.loo}} method.
 #'   
 #' @examples 
-#' \dontrun{
+#' \donttest{
 #' SEED <- 42024
 #' set.seed(SEED)
 #' 
@@ -111,8 +111,8 @@
 #' fit2 <- update(fit1, formula = . ~ . + cyl)
 #' 
 #' # compare on LOOIC
-#' (loo1 <- loo(fit1))
-#' loo2 <- loo(fit2)
+#' (loo1 <- loo(fit1, cores = 2))
+#' loo2 <- loo(fit2, cores = 2)
 #' compare(loo1, loo2)
 #' plot(loo2)
 #' 
@@ -128,15 +128,15 @@
 #' f1 <- treat ~ re74 + re75 + educ + black + hisp + married + 
 #'    nodegr + u74 + u75
 #' lalonde1 <- stan_glm(f1, data = lalonde, family = binomial(link="logit"), 
-#'                      prior = t7, cores = 4, seed = SEED)
+#'                      prior = t7, cores = 2, seed = SEED)
 #'                  
 #' f2 <- treat ~ age + I(age^2) + educ + I(educ^2) + black + hisp + 
 #'    married + nodegr + re74  + I(re74^2) + re75 + I(re75^2) + u74 + u75   
 #' lalonde2 <- update(lalonde1, formula = f2)
 #' 
 #' # compare on LOOIC
-#' (loo_lalonde1 <- loo(lalonde1))
-#' (loo_lalonde2 <- loo(lalonde2))
+#' (loo_lalonde1 <- loo(lalonde1, cores = 2))
+#' (loo_lalonde2 <- loo(lalonde2, cores = 2))
 #' plot(loo_lalonde2, label_points = TRUE)
 #' compare(loo_lalonde1, loo_lalonde2)
 #' }
@@ -146,6 +146,8 @@
 loo.stanreg <- function(x, ..., k_threshold = NULL) {
   if (!used.sampling(x)) 
     STOP_sampling_only("loo")
+  if (length(x[["weights"]]) && !all(x[["weights"]] == 1))
+    recommend_exact_loo(reason = "model has weights")
   
   user_threshold <- !is.null(k_threshold)
   if (user_threshold) {
@@ -213,6 +215,15 @@ recommend_reloo <- function(n) {
     call. = FALSE
   )
 }
+recommend_exact_loo <- function(reason) {
+  stop(
+    "'loo' is not supported if ", reason, ". ", 
+    "If refitting the model 'nobs(x)' times is feasible, ", 
+    "we recommend calling 'kfold' with K equal to the ", 
+    "total number of observations in the data to perform exact LOO-CV.",
+    call. = FALSE
+  )
+}
 
 
 #' @rdname loo.stanreg
@@ -228,10 +239,11 @@ kfold <- function(x, K = 10) {
   validate_stanreg_object(x)
   if (!used.sampling(x)) 
     STOP_sampling_only("kfold")
-  stopifnot(!is.null(x$data), nrow(x$data) >= K)
+  stopifnot(!is.null(x$data), K > 1, nrow(x$data) >= K)
   
   d <- x$data
   N <- nrow(d)
+  wts <- x[["weights"]]
   perm <- sample.int(N)
   idx <- ceiling(seq(from = 1, to = N, length.out = K + 1))
   bin <- .bincode(perm, breaks = idx, right = FALSE, include.lowest = TRUE)
@@ -240,7 +252,12 @@ kfold <- function(x, K = 10) {
   for (k in 1:K) {
     message("Fitting model ", k, " out of ", K)
     omitted <- which(bin == k)
-    fit_k <- update(x, data = d[-omitted, ], refresh = 0)
+    fit_k <- update(
+      object = x,
+      data = d[-omitted,],
+      weights = if (length(wts)) wts[-omitted] else NULL,
+      refresh = 0
+    )
     lppds[[k]] <- log_lik(fit_k, newdata = d[omitted, ])
   }
   elpds <- unlist(lapply(lppds, function(x) {
@@ -312,7 +329,7 @@ reloo <- function(x, loo_x, obs, ..., refit = TRUE) {
       " (leaving out observation ", obs[j], ")"
     )
     omitted <- obs[j]
-    fit_j <- update(x, data = d[-omitted, ], refresh = 0)
+    fit_j <- suppressWarnings(update(x, data = d[-omitted, ], refresh = 0))
     lls[[j]] <- log_lik(fit_j, newdata = d[omitted, ])
   }
   
@@ -352,13 +369,13 @@ ll_fun <- function(x) {
 
 # arguments for loo.function ----------------------------------------------
 # returns 'args' argument for loo.function() and waic.function()
-ll_args <- function(object, newdata = NULL) {
+ll_args <- function(object, newdata = NULL, offset = NULL) {
   validate_stanreg_object(object)
   f <- family(object)
   draws <- nlist(f)
   has_newdata <- !is.null(newdata)
   if (has_newdata) {
-    ppdat <- pp_data(object, as.data.frame(newdata))
+    ppdat <- pp_data(object, as.data.frame(newdata), offset = offset)
     tmp <- pp_eta(object, ppdat)
     eta <- tmp$eta
     stanmat <- tmp$stanmat
