@@ -76,7 +76,7 @@ set_sampling_args <- function(object, prior, user_dots = list(),
 default_stan_control <- function(prior, adapt_delta = NULL, 
                                  max_treedepth = 15L) {
   if (is.null(prior)) {
-    adapt_delta <- 0.95
+    if (is.null(adapt_delta)) adapt_delta <- 0.95
   } else if (is.null(adapt_delta)) {
     adapt_delta <- switch(prior$dist, 
                           "R2" = 0.99,
@@ -315,6 +315,14 @@ b_names <- function(x, ...) {
   grep("^b\\[", x, ...)
 }
 
+# Return names of the last dimension in a matrix/array (e.g. colnames if matrix)
+#
+# @param x A matrix or array
+last_dimnames <- function(x) {
+  ndim <- length(dim(x))
+  dimnames(x)[[ndim]]
+}
+
 # Get the correct column name to use for selecting the median
 #
 # @param algorithm String naming the estimation algorithm (probably
