@@ -24,8 +24,6 @@ ITER <- 40 # small iter for speed but large enough for psis
 REFRESH <- 0
 
 SW <- suppressWarnings
-ll_fun <- rstanarm:::ll_fun
-
 
 # loo and waic ------------------------------------------------------------
 context("loo and waic")
@@ -61,6 +59,13 @@ test_that("loo & waic throw error for non mcmc models", {
   mcmc_only_error(fitvb2)
 })
 
+test_that("loo errors if model has weights", {
+  fit <- stan_glm(mpg ~ wt, data = mtcars, weights = rep_len(c(1,2), nrow(mtcars)), 
+                  seed = SEED, refresh = REFRESH, iter = 50)
+  expect_error(loo(fit), "not supported")
+  expect_error(loo(fit), "'kfold'")
+})
+
 test_that("loo/waic for stan_glm works", {
   # gaussian
   fit_gaus <- SW(stan_glm(mpg ~ wt, data = mtcars, chains = CHAINS, iter = ITER, 
