@@ -266,18 +266,91 @@ test_that("coef ok if any 'ranef' missing from 'fixef'", {
 })
 
 
-test_that("as.matrix and as.data.frame methods work", {
+test_that("as.matrix, as.data.frame, as.array methods work for MCMC", {
+  # glm
   mat <- as.matrix(stan_glm1)
   df <- as.data.frame(stan_glm1)
+  arr <- as.array(stan_glm1)
   expect_identical(df, as.data.frame(mat))
-  expect_equal(dim(mat), c(ITER, 3L))
-  expect_identical(colnames(mat), c("(Intercept)", "wt", "sigma"))
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  expect_equal(dim(mat), c(floor(ITER/2) * CHAINS, 3L))
+  expect_equal(dim(arr), c(floor(ITER/2), CHAINS, 3L))
+  expect_identical(last_dimnames(mat), c("(Intercept)", "wt", "sigma"))
+  expect_identical(last_dimnames(arr), last_dimnames(mat))
+  
+  # selecting only 1 parameter
   mat <- as.matrix(stan_glm1, pars = "wt")
   df <- as.data.frame(stan_glm1, pars = "wt")
+  arr <- as.array(stan_glm1, pars = "wt")
   expect_identical(df, as.data.frame(mat))
-  expect_equal(dim(mat), c(ITER, 1L))
-  expect_identical(colnames(mat), "wt")
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  expect_equal(dim(mat), c(floor(ITER/2) * CHAINS, 1L))
+  expect_equal(dim(arr), c(floor(ITER/2), CHAINS, 1L))
+  expect_identical(last_dimnames(mat), "wt")
+  expect_identical(last_dimnames(arr), last_dimnames(mat))
   
+  # glmer
+  mat <- as.matrix(example_model)
+  df <- as.data.frame(example_model)
+  arr <- as.array(example_model)
+  expect_identical(df, as.data.frame(mat))
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  nc <- length(c(fixef(example_model), unlist(ranef(example_model))))
+  nr <- posterior_sample_size(example_model)
+  nms <- rownames(summary(example_model))[seq_len(nc)]
+  expect_equal(dim(mat), c(nr, nc))
+  expect_equal(dim(arr), c(nr / 2, 2, nc))
+  expect_identical(last_dimnames(mat), nms)
+  expect_identical(last_dimnames(mat), last_dimnames(arr))
+  
+  # pars & regex_pars
+  mat <- as.matrix(example_model, pars = "mean_PPD", regex_pars = "period")
+  df <- as.data.frame(example_model, pars = "mean_PPD", regex_pars = "period")
+  arr <- as.array(example_model, pars = "mean_PPD", regex_pars = "period")
+  expect_identical(df, as.data.frame(mat))
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  expect_equal(dim(mat), c(nr, 4L))
+  expect_equal(dim(arr), c(nr/2, 2, 4L))
+  expect_identical(last_dimnames(mat), c("mean_PPD", paste0("period", 2:4)))
+  expect_identical(last_dimnames(mat), last_dimnames(arr))
+  
+  # lmer
+  mat <- as.matrix(stan_lmer1)
+  df <- as.data.frame(stan_lmer1)
+  arr <- as.array(stan_lmer1)
+  expect_identical(df, as.data.frame(mat))
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  nc <- length(c(fixef(stan_lmer1), unlist(ranef(stan_lmer1)))) + 1 # +1 for "sigma"
+  nms <- rownames(summary(stan_lmer1))[seq_len(nc)]
+  expect_equal(dim(mat), c(floor(ITER/2) * CHAINS, nc))
+  expect_equal(dim(arr), c(floor(ITER/2), CHAINS, nc))
+  expect_identical(last_dimnames(mat), nms)
+  expect_identical(last_dimnames(mat), last_dimnames(arr))
+  mat <- as.matrix(stan_lmer1, pars = "(Intercept)", regex_pars = "sample")
+  df <- as.data.frame(stan_lmer1, pars = "(Intercept)", regex_pars = "sample")
+  expect_identical(df, as.data.frame(mat))
+  s <- summary(stan_lmer1, pars = "(Intercept)", regex_pars = "sample")
+  expect_equal(dim(mat), c(floor(ITER/2) * CHAINS, nrow(s)))
+  expect_identical(colnames(mat), rownames(s))
+  
+  # polr
+  mat <- as.matrix(stan_polr1)
+  df <- as.data.frame(stan_polr1)
+  arr <- as.array(stan_polr1)
+  expect_identical(df, as.data.frame(mat))
+  expect_identical(mat[1:2, 1], arr[1:2, 1, 1])
+  nms <- names(c(stan_polr1$coefficients, stan_polr1$zeta))
+  expect_equal(dim(mat), c(floor(ITER/2) * CHAINS, length(nms)))
+  expect_equal(dim(arr), c(floor(ITER/2), CHAINS, length(nms)))
+  expect_identical(last_dimnames(mat), nms)
+  expect_identical(last_dimnames(mat), last_dimnames(arr))
+  mat <- as.matrix(stan_polr1, regex_pars = "\\^")
+  df <- as.data.frame(stan_polr1, regex_pars = "\\^")
+  expect_identical(df, as.data.frame(mat))
+  expect_identical(colnames(mat), paste0("agegp^", 4:5))
+})
+test_that("as.matrix and as.data.frame work for optimization and vb", {
+  # optimization
   mat <- as.matrix(stan_glm_opt1)
   df <- as.data.frame(stan_glm_opt1)
   expect_identical(df, as.data.frame(mat))
@@ -289,6 +362,7 @@ test_that("as.matrix and as.data.frame methods work", {
   expect_equal(dim(mat), c(1000, 1L))
   expect_identical(colnames(mat), "sigma")
   
+  # vb
   mat <- as.matrix(stan_glm_vb1)
   df <- as.data.frame(stan_glm_vb1)
   expect_identical(df, as.data.frame(mat))
@@ -299,47 +373,15 @@ test_that("as.matrix and as.data.frame methods work", {
   expect_identical(df, as.data.frame(mat))
   expect_equal(dim(mat), c(1000, 2L))
   expect_identical(colnames(mat), c("(Intercept)", "sigma"))
+})
+test_that("as.matrix and as.array errors & warnings", {
+  # optimization and vb errors
+  expect_error(as.array(stan_glm_opt1), 
+               regexp = "use 'as.matrix' instead")
+  expect_error(as.array(stan_glm_vb1), 
+               regexp = "use 'as.matrix' instead")
   
-  mat <- as.matrix(example_model)
-  df <- as.data.frame(example_model)
-  expect_identical(df, as.data.frame(mat))
-  nc <- length(c(fixef(example_model), unlist(ranef(example_model))))
-  nr <- rstanarm:::posterior_sample_size(example_model)
-  nms <- rownames(summary(example_model))[seq_len(nc)]
-  expect_equal(dim(mat), c(nr, nc))
-  expect_identical(colnames(mat), nms)
-  mat <- as.matrix(example_model, pars = "mean_PPD", regex_pars = "period")
-  df <- as.data.frame(example_model, pars = "mean_PPD", regex_pars = "period")
-  expect_identical(df, as.data.frame(mat))
-  expect_equal(dim(mat), c(nr, 4L))
-  expect_identical(colnames(mat), c("mean_PPD", paste0("period", 2:4)))
-  
-  mat <- as.matrix(stan_lmer1)
-  df <- as.data.frame(stan_lmer1)
-  expect_identical(df, as.data.frame(mat))
-  nc <- length(c(fixef(stan_lmer1), unlist(ranef(stan_lmer1)))) + 1 # +1 for "sigma"
-  nms <- rownames(summary(stan_lmer1))[seq_len(nc)]
-  expect_equal(dim(mat), c(ITER, nc))
-  expect_identical(colnames(mat), nms)
-  mat <- as.matrix(stan_lmer1, pars = "(Intercept)", regex_pars = "sample")
-  df <- as.data.frame(stan_lmer1, pars = "(Intercept)", regex_pars = "sample")
-  expect_identical(df, as.data.frame(mat))
-  s <- summary(stan_lmer1, pars = "(Intercept)", regex_pars = "sample")
-  expect_equal(dim(mat), c(ITER, nrow(s)))
-  expect_identical(colnames(mat), rownames(s))
-  
-  mat <- as.matrix(stan_polr1)
-  df <- as.data.frame(stan_polr1)
-  expect_identical(df, as.data.frame(mat))
-  nms <- names(c(stan_polr1$coefficients, stan_polr1$zeta))
-  expect_equal(dim(mat), c(ITER, length(nms)))
-  expect_identical(colnames(mat), nms)
-  mat <- as.matrix(stan_polr1, regex_pars = "\\^")
-  df <- as.data.frame(stan_polr1, regex_pars = "\\^")
-  expect_identical(df, as.data.frame(mat))
-  expect_identical(colnames(mat), paste0("agegp^", 4:5))
-  
-  
+  # pars and regex_pars errors
   expect_error(as.matrix(stan_glm1, pars = c("bad1", "sigma")), 
                regexp = "No parameter(s) bad1", fixed = TRUE)
   expect_error(as.matrix(stan_glm1, regex_pars = "not a parameter"), 
