@@ -31,12 +31,16 @@ if (interactive()) options(mc.cores = parallel::detectCores())
 FIXEF_tol <- 0.05
 RANEF_tol <- 0.20 
 
+expect_stanreg <- function(x) expect_s3_class(x, "stanreg")
+
 
 context("stan_lmer")
 test_that("stan_lmer returns expected result for slepstudy example", {
   fmla <- Reaction / 10 ~ Days + (Days | Subject)
   fit <- stan_lmer(fmla, data = sleepstudy, refresh = REFRESH,
                    init_r = 0.05, chains = CHAINS, iter = ITER, seed = SEED)
+  expect_stanreg(fit)
+  
   ans <- lmer(fmla, data = sleepstudy)
   expect_equal(fixef(fit), fixef(ans), tol = FIXEF_tol)
   # expect_equal(ranef(fit), ranef(ans), tol = RANEF_tol)
@@ -47,7 +51,9 @@ context("stan_lmer")
 test_that("stan_lmer returns expected result for Penicillin example", {
   fmla <- as.formula(diameter ~ (1|plate) + (1|sample))
   fit <- stan_lmer(fmla, data = Penicillin, chains = CHAINS, iter = ITER, 
-                   seed = SEED, refresh = REFRESH)
+                   seed = SEED, refresh = REFRESH, sparse = TRUE)
+  expect_stanreg(fit)
+  
   ans <- lmer(fmla, data = Penicillin)
   expect_equal(fixef(fit), fixef(ans), tol = FIXEF_tol)
   expect_equal(ranef(fit), ranef(ans), tol = RANEF_tol)
@@ -62,6 +68,8 @@ test_that("stan_glmer returns expected result for cbpp example", {
     fmla <- cbind(incidence, size - incidence) ~ period + (1 | herd)
     fit <- stan_glmer(fmla, data = cbpp, family = binomial(links[i]),
                       chains = CHAINS, iter = ITER, seed = SEED, refresh = REFRESH)
+    expect_stanreg(fit)
+    
     ans <- glmer(fmla, data = cbpp, family = binomial(links[i]))
     expect_equal(fixef(fit), fixef(ans), tol = FIXEF_tol)
     expect_equal(ranef(fit), ranef(ans), tol = RANEF_tol)
@@ -76,11 +84,13 @@ test_that("stan_glmer returns expected result for bernoulli (lalonde)", {
   })
   fmla <- treat ~ (1|black) + re74_1k + re75_1k + educ + hisp +
     married + nodegr + u74 + u75
-  fit <- stan_glmer(fmla, data = dat, family = binomial(link = "logit"),
+  fit <- stan_glmer(fmla, data = dat, family = binomial(link = "logit"), sparse = TRUE,
                     prior = student_t(7), prior_intercept = normal(0, 2.5),
                     iter = ITER, chains = CHAINS, seed = SEED, refresh = REFRESH)
+  expect_stanreg(fit)
+  
   ans <- glmer(fmla, data = dat, family = binomial(link = "logit"))
-  expect_equal(fixef(fit), fixef(ans), tol = 0.1)
+  expect_equal(fixef(fit)[-1], fixef(ans)[-1], tol = 0.1)
   expect_equal(ranef(fit), ranef(ans), tol = RANEF_tol)
   expect_equal(ngrps(fit), ngrps(ans))
 })
@@ -95,6 +105,8 @@ test_that("stan_glmer.nb ok", {
   fmla <- as.formula(y ~ f1*f2 + (1|g))
   fit <- stan_glmer.nb(formula = fmla, data = dd, chains = CHAINS, iter = ITER, 
                        seed = SEED, refresh = REFRESH)
+  expect_stanreg(fit)
+  
   ans <- glmer.nb(formula = fmla, data = dd)
   # ans is messed up
   # expect_equal(fixef(fit), fixef(ans), tol = FIXEF_tol)
@@ -104,9 +116,11 @@ test_that("stan_glmer.nb ok", {
 
 context("stan_gamm4")
 test_that("stan_gamm4 returns expected result for sleepstudy example", {
-  fit <- stan_gamm4(Reaction / 10 ~ s(Days), data = sleepstudy,
+  fit <- stan_gamm4(Reaction / 10 ~ s(Days), data = sleepstudy, sparse = TRUE,
                     random = ~(1|Subject), chains = CHAINS, iter = ITER, 
                     seed = SEED, refresh = REFRESH)
+  expect_stanreg(fit)
+  
   ans <- gamm4(Reaction / 10 ~ s(Days), data = sleepstudy, 
                random = ~(1|Subject))$mer
   expect_equal(fixef(fit)[-1], fixef(ans)[-1], tol = FIXEF_tol)
@@ -119,4 +133,10 @@ test_that("stan_lmer returns an error when multiple group-specific terms are spe
   expect_error(stan_lmer(Reaction / 10 ~ Days + (Days | Subject) + (1|Subject), 
                          data = sleepstudy, chains = 1))
 })
+
+test_that("stan_lmer ok if global intercept forced to 0", {
+  expect_stanreg(stan_lmer(mpg ~ 0 + (1|cyl), data = mtcars, iter = 10, 
+                           seed = SEED))
+})
+
   
\ No newline at end of file
